{% load carton_tags %}
<html>
<body>

<h1>Shopping Cart</h1>

{% get_cart as cart %}

    <table border="1">
    <tr>
        <th>Product</th>
        <th>Quantity</th>
        <th>Price</th>
    </tr>
    {% for item in cart.items %}
    <tr>
        <td>{{ item.product }}</td>
        <td>{{ item.quantity }}</td>
        <td>{{ item.subtotal }}</td>
    </tr>
        {% endfor %}
    </table>

    Total: {{ cart.total }}

</body>
</html>
